================================
 os-client-config Release Notes
================================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   queens
   pike
   ocata
   newton
   mitaka

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
